@@ -26,13 +26,12 @@ __license__ = "Apache 2.0"
 import kineticstoolkit.config
 import kineticstoolkit._repr as _repr
 import kineticstoolkit.gui
-from kineticstoolkit.decorators import directory
+import kineticstoolkit.ext
 
-import webbrowser as _webbrowser
 import warnings
 
 
-def start_lab_mode(
+def change_defaults(
     change_ipython_dict_repr: bool = True,
     change_matplotlib_defaults: bool = True,
     change_numpy_print_options: bool = True,
@@ -43,79 +42,88 @@ def start_lab_mode(
 
     This function does not affect Kinetics Toolkit's inner working. It exists
     mostly for cosmetic reasons, so that working with ktk in an IPython console
-    (e.g., Spyder, Jupyter) is more enjoyable, at least to the developer's
-    taste. It changes defaults and is not reversible in a given session. The
-    usual way to call it is right after importing Kinetics Toolkit.
+    (e.g., Spyder, Jupyter) is more enjoyable. It changes IPython, Matplotlib
+    and numpy's defaults for the current session only. The usual way to call
+    it is right after importing Kinetics Toolkit.
 
     Parameters
     ----------
     change_ipython_dict_repr
-        True to summarize defaults dict printouts in IPython.
+        Optional. True to summarize defaults dict printouts in IPython. When
+        False, dict printouts look like::
+
+            {'data1': array([ 0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15, 16,
+                             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29]),
+             'data2': array([  0,   1,   4,   9,  16,  25,  36,  49,  64,  81, 100, 121, 144,
+                             169, 196, 225, 256, 289, 324, 361, 400, 441, 484, 529, 576, 625,
+                              676, 729, 784, 841])}
+
+        When True, dict printouts look like::
+
+            {
+                'data1': <array of shape (30,)>
+                'data2': <array of shape (30,)>
+            }
+
     change_matplotlib_defaults
-        True to change default figure size, autolayout, dpi, line width
-        and color order in Matplotlib.
+        Optional. True to change default figure size, autolayout, dpi, line
+        width and color order in Matplotlib. The dpi and figure size are
+        optimized for interactive work in default matplotlib figures.
+        Additionally, the default color order is changed to (rgbcmyko).
+        The first colors, (rgb) are consistent with the colours assigned to
+        x, y and z in most 3D visualization softwares.
+
     change_numpy_print_options
-        True to change default print options in numpy to use fixed point
-        notation in printouts.
+        Optional. True to change default print options in numpy to use fixed
+        point notation in printouts.
+
     change_warnings_format
-        True to change warnings module's default to a more extended format
-        with file and line number.
+        Optional. True to change warnings module's default to a more extended
+        format with file and line number.
 
     Returns
     -------
     None
 
+    Note
+    ----
+    This function is called automatically when importing Kinetics Toolkit in
+    lab mode::
+
+        import kineticstoolkit.lab as ktk
+
     """
     if change_ipython_dict_repr:
         # Modify the repr function for dicts in IPython
         try:
             import IPython as _IPython
+
             _ip = _IPython.get_ipython()
-            formatter = _ip.display_formatter.formatters['text/plain']
-            formatter.for_type(dict, lambda n, p, cycle:
-                               _repr._ktk_format_dict(n, p, cycle))
+            formatter = _ip.display_formatter.formatters["text/plain"]
+            formatter.for_type(
+                dict, lambda n, p, cycle: _repr._ktk_format_dict(n, p, cycle)
+            )
         except Exception:
             pass
 
     if change_matplotlib_defaults:
         # Set alternative defaults to matplotlib
         import matplotlib as _mpl
-        _mpl.rcParams['figure.figsize'] = [10, 5]
-        _mpl.rcParams['figure.dpi'] = 75
-        _mpl.rcParams['lines.linewidth'] = 1
-        kineticstoolkit.gui.set_color_order('xyz')
+
+        _mpl.rcParams["figure.figsize"] = [10, 5]
+        _mpl.rcParams["figure.dpi"] = 75
+        _mpl.rcParams["lines.linewidth"] = 1
+        kineticstoolkit.gui.set_color_order("xyz")
 
     if change_numpy_print_options:
         import numpy as _np
+
         # Select default mode for numpy
         _np.set_printoptions(suppress=True)
 
     if change_warnings_format:
         # Monkey-patch warning.formatwarning
         def formatwarning(message, category, filename, lineno, line=None):
-            return f'{category.__name__} [{filename}:{lineno}] {message}\n'
+            return f"{category.__name__} [{filename}:{lineno}] {message}\n"
+
         warnings.formatwarning = formatwarning
-
-
-def tutorials() -> None:
-    """
-    Open the Kinetics Toolkits tutorials in a web browser.
-
-    Usage: ktk.tutorials()
-
-    Warning
-    -------
-    This function, which has been introduced in 0.3, is still experimental and
-    may change signature or behaviour in the future.
-
-    """
-    _webbrowser.open('file:///' + kineticstoolkit.config.root_folder +
-                     '/tutorials/index.html',
-                     new=2)
-
-
-module_locals = locals()
-
-
-def __dir__():
-    return directory(module_locals)
